###########################
Structure and content modes
###########################


The *Structure/Content* mode control in the toolbar lets you switch between two different editing
modes.

You've already used *Content* mode, in which you can double-click on content to edit it.

In *Structure* mode, you can manage the placement of content within the page structure.

Switch to *Structure* mode. This reveals the *structure board* containing the *placeholders*
available on the page, and the *plugins* in them:

.. image:: /user/tutorial/images/structure-board.png
     :align: right
     :alt: the structure board

Here there is just one placeholder, called *Content*, containing one plugin - a text plugin that
begins *Lorem ipsum dolor...*.

.. image:: /user/tutorial/images/add-plugin.png
     :alt: the 'Add plugin' icon
     :width: 308


*******************
Add a second plugin
*******************

Let's add another plugin.

Select the **Add plugin** icon (**+**) and choose *Text* from the list of available plugin types.

.. image:: /user/tutorial/images/text-plugin.png
     :alt: the list of plugin types
     :width: 165

This will open a familiar text editor; add some text and **Save**. Now in the structure board
you'll see the new *Text* plugin - which you can move around within the structure, to re-order the
plugins.

.. note::

    You don't need to save these changes manually - they are saved automatically as soon as you make
    them. However, they still need to be published in order for other users to see them.

Each plugin in the structure board is available for editing by double-clicking or selecting the
edit icon.

.. image:: /user/tutorial/images/structure-board-with-two-plugins.png
   :alt: the structure board with two plugins

You can switch back to content mode to see the effect of your changes, and **Publish** the page to
make them public.
